/*
 * %kadu copyright begin%
 * Copyright 2009, 2010 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * Copyright 2010 Tomasz Rostański (rozteck@interia.pl)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef PERSONAL_INFO_SERVICE_H
#define PERSONAL_INFO_SERVICE_H

#include <QtCore/QObject>

#include "buddies/buddy.h"
#include "exports.h"

class KADUAPI PersonalInfoService : public QObject
{
	Q_OBJECT

public:
	explicit PersonalInfoService(QObject *parent) : QObject(parent) {}

	virtual void updatePersonalInfo(Buddy buddy) = 0;
	virtual void fetchPersonalInfo() = 0;

signals:
	void personalInfoAvailable(Buddy buddy);
	void personalInfoUpdated(bool);

};

#endif // PERSONAL_INFO_SERVICE_H
